import { computed, Ref } from 'vue'
import { ID } from '@/api'

export function useItems<T extends { id: ID; isActive: boolean; name: string }>(
  objects: Ref<T[]>,
  usedIds: Ref<ID | undefined | null | ID[]>,
) {
  const idMap = computed(() => new Map(objects.value.map((obj) => [obj.id, obj])))
  const choices = computed(() =>
    objects.value.map((obj) => ({ value: obj.id, text: obj.name, disabled: !obj.isActive })),
  )
  const usedItems = computed(() => {
    const value = usedIds.value
    return (Array.isArray(value) ? value : value ? [value] : [])
      .filter((id) => idMap.value.has(id))
      .map((id) => idMap.value.get(id) as T)
  })
  const usedItem = computed(() => usedItems.value[0])
  return { choices, usedItem, usedItems }
}
